@@ -171,6 +171,7 @@ public:
     void updateChoices(const QStringList &choices);
 
     QString selectedApplication() const;
+    QString activationToken() const;
 private Q_SLOTS:
     void onApplicationSelected(const QString &desktopFile, const bool remember = false);
     void onOpenDiscover();
@@ -178,6 +179,7 @@ private Q_SLOTS:
 private:
     AppModel *const m_model;
     QString m_selectedApplication;
+    QString m_activationToken;
     AppChooserData *const m_appChooserData;
 };
 
